This repository contains 
  the code and data I used to analyze the deaths of a million citations in Sociology articles.
The repository provides code and documentation for producing all analyses and figures in the final paper.

# Installation

1. Install Python 3.7
2. Run `pip install science2-amcgail`

# Quick start

The following command starts jupyterlab in the base directory of this repository. This is a good place to start.

`python -m science2 start`
